Coverage for src/paperap/resources/tags.py: 100%

1"""

2----------------------------------------------------------------------------

3

4 METADATA:

5

6 File: tags.py

7 Project: paperap

8 Created: 2025-03-04

9 Version: 0.0.5

10 Author: Jess Mann

11 Email: jess@jmann.me

12 Copyright (c) 2025 Jess Mann

13

14----------------------------------------------------------------------------

15

16 LAST MODIFIED:

17

18 2025-03-04 By Jess Mann

19

20"""

21

22 from __future__ import annotations

23

24 from paperap.models.tag import Tag, TagQuerySet

25 from paperap.resources.base import BaseResource, StandardResource

26

27

28 class TagResource(StandardResource[Tag, TagQuerySet]):

29 """Resource for managing tags."""

30

31 model_class = Tag

32 name = "tags"